import { Logger } from '../../Diagnostics/Logger';
export function validateDirectedAcyclicGraph(graph) {
    Object.values(graph.nodes).forEach((node) => {
        node.metadata['dag.marked'] = 'false';
    });
    Logger.verbose(`total nodes: ${Object.values(graph.nodes).length}`);
    const nodesToMark = [];
    do {
        nodesToMark.length = 0;
        Object.values(graph.nodes).forEach((node) => {
            if (node.metadata['dag.marked'] === 'true') {
                return;
            }
            let inputSocketsConnected = false;
            node.inputSockets.forEach((inputSocket) => {
                inputSocket.links.forEach((link) => {
                    if (graph.nodes[link.nodeId].metadata['dag.marked'] === 'false') {
                        inputSocketsConnected = true;
                    }
                });
            });
            if (!inputSocketsConnected) {
                nodesToMark.push(node);
            }
        });
        Logger.verbose(`marking ${nodesToMark.length} nodes`);
        nodesToMark.forEach((node) => {
            node.metadata['dag.marked'] = 'true';
        });
    } while (nodesToMark.length > 0);
    const errorList = [];
    Object.values(graph.nodes).forEach((node) => {
        Logger.verbose(`node ${node.typeName} is marked ${node.metadata['dag.marked']}`);
        if (node.metadata['dag.marked'] === 'false') {
            errorList.push(`node ${node.typeName} is part of a cycle, not a directed acyclic graph`);
        }
        delete node.metadata['dag.marked'];
    });
    return errorList;
}
//# sourceMappingURL=validateDirectedAcyclicGraph.js.map