export class Node {
    constructor(description, graph, inputSockets = [], outputSockets = []) {
        this.description = description;
        this.graph = graph;
        this.inputSockets = inputSockets;
        this.outputSockets = outputSockets;
        this.id = '';
        this.label = '';
        this.metadata = {};
    }
    readInput(inputName) {
        const inputSocket = this.inputSockets.find((socket) => socket.name === inputName);
        if (inputSocket === undefined) {
            throw new Error(`can not find input socket with name ${inputName} on node of type ${this.description.typeName}`);
        }
        return inputSocket.value;
    }
    writeOutput(outputName, value) {
        const outputSocket = this.outputSockets.find((socket) => socket.name === outputName);
        if (outputSocket === undefined) {
            throw new Error(`can not find output socket with name ${outputSocket} on node of type ${this.description.typeName}`);
        }
        if (outputSocket.valueTypeName === 'flow') {
            throw new Error(`can not set the value of Flow output socket ${outputName}, use commit() instead`);
        }
        outputSocket.value = value;
    }
}
//# sourceMappingURL=Node.js.map