import { Assert } from '../Diagnostics/Assert.js';
import { generateUuid } from '../generateUuid.js';
export class NodeTypeRegistry {
    constructor() {
        this.nodeTypeNameToNodeFactory = {};
    }
    register(nodeTypeName, nodeTypeFactory) {
        if (nodeTypeName in this.nodeTypeNameToNodeFactory) {
            throw new Error(`already registered node type ${nodeTypeName}`);
        }
        this.nodeTypeNameToNodeFactory[nodeTypeName] = nodeTypeFactory;
    }
    create(nodeTypeName, nodeId = generateUuid()) {
        if (!(nodeTypeName in this.nodeTypeNameToNodeFactory)) {
            throw new Error(`no registered node with type name ${nodeTypeName}`);
        }
        const factory = this.nodeTypeNameToNodeFactory[nodeTypeName];
        const node = factory();
        node.id = nodeId;
        Assert.mustBeTrue(node.typeName === nodeTypeName, `node.typeName: ${node.typeName} must align with registered typeName: ${nodeTypeName}`);
        return node;
    }
    getAllNames() {
        return Object.keys(this.nodeTypeNameToNodeFactory);
    }
}
//# sourceMappingURL=NodeTypeRegistry.js.map