import { FlowNode } from '../../../Nodes/FlowNode.js';
import { NodeDescription } from '../../../Nodes/Registry/NodeDescription.js';
import { Socket } from '../../../Sockets/Socket.js';
export class TriggerCustomEvent extends FlowNode {
    constructor(description, graph, customEvent) {
        super(description, graph, [
            new Socket('flow', 'flow'),
            ...customEvent.parameters.map((parameter) => new Socket(parameter.valueTypeName, parameter.name, parameter.value, parameter.label))
        ], [new Socket('flow', 'flow')]);
        this.customEvent = customEvent;
    }
    static GetDescription(graph, customEventId) {
        const customEvent = graph.customEvents[customEventId];
        return new NodeDescription(`customEvent/trigger/${customEvent.id}`, 'Action', `Trigger ${customEvent.name}`, (description, graph) => new TriggerCustomEvent(description, graph, customEvent));
    }
    triggered(fiber, triggeringSocketName) {
        const parameters = {};
        this.customEvent.parameters.forEach((parameterSocket) => {
            parameters[parameterSocket.name] = this.readInput(parameterSocket.name);
        });
        this.customEvent.eventEmitter.emit(parameters);
    }
}
//# sourceMappingURL=TriggerCustomEvent.js.map