import { AsyncNode } from '../../../Nodes/AsyncNode.js';
import { NodeDescription } from '../../../Nodes/Registry/NodeDescription.js';
import { Socket } from '../../../Sockets/Socket.js';
export class Debounce extends AsyncNode {
    constructor(description, graph) {
        super(description, graph, [
            new Socket('flow', 'flow'),
            new Socket('float', 'waitDuration'),
            new Socket('flow', 'cancel')
        ], [new Socket('flow', 'flow')]);
        this.triggerVersion = 0;
    }
    triggered(engine, triggeringSocketName, finished) {
        this.triggerVersion++;
        if (triggeringSocketName === 'cancel') {
            return;
        }
        const localTriggerCount = this.triggerVersion;
        setTimeout(() => {
            if (this.triggerVersion >= localTriggerCount) {
                return;
            }
            engine.commitToNewFiber(this, 'flow');
            finished();
        }, this.readInput('waitDuration') * 1000);
    }
    dispose() {
        this.triggerVersion++;
    }
}
Debounce.Description = new NodeDescription('flow/debounce', 'Flow', 'Debounce', (description, graph) => new Debounce(description, graph));
//# sourceMappingURL=Debounce.js.map