import { Assert } from '../../../Diagnostics/Assert.js';
import { AsyncNode } from '../../../Nodes/AsyncNode.js';
import { NodeDescription } from '../../../Nodes/Registry/NodeDescription.js';
import { Socket } from '../../../Sockets/Socket.js';
export class Delay extends AsyncNode {
    constructor(description, graph) {
        super(description, graph, [
            new Socket('flow', 'flow'),
            new Socket('float', 'duration'),
            new Socket('flow', 'cancel')
        ], [new Socket('flow', 'flow')]);
        this.triggerVersion = 0;
        this.timeoutPending = false;
    }
    triggered(engine, triggeringSocketName, finished) {
        if (triggeringSocketName === 'cancel') {
            if (this.timeoutPending) {
                this.triggerVersion++;
                this.timeoutPending = false;
            }
            return;
        }
        if (this.timeoutPending) {
            return;
        }
        this.triggerVersion++;
        const localTriggerCount = this.triggerVersion;
        this.timeoutPending = true;
        setTimeout(() => {
            if (this.triggerVersion !== localTriggerCount) {
                return;
            }
            Assert.mustBeTrue(this.timeoutPending);
            this.timeoutPending = false;
            engine.commitToNewFiber(this, 'flow');
            finished();
        }, this.readInput('duration') * 1000);
    }
    dispose() {
        this.triggerVersion++;
        this.timeoutPending = false;
    }
}
Delay.Description = new NodeDescription('flow/delay', 'Flow', 'Delay', (description, graph) => new Delay(description, graph));
//# sourceMappingURL=Delay.js.map