import { FlowNode } from '../../../Nodes/FlowNode.js';
import { NodeDescription } from '../../../Nodes/Registry/NodeDescription.js';
import { Socket } from '../../../Sockets/Socket.js';
import { toCamelCase } from '../../../toCamelCase.js';
export class SetSceneProperty extends FlowNode {
    constructor(description, graph, valueTypeName, scene) {
        super(description, graph, [
            new Socket('flow', 'flow'),
            new Socket('string', 'jsonPath'),
            new Socket(valueTypeName, 'value')
        ], [new Socket('flow', 'flow')]);
        this.valueTypeName = valueTypeName;
        this.scene = scene;
    }
    static GetDescriptions(scene, ...valueTypeNames) {
        return valueTypeNames.map((valueTypeName) => new NodeDescription(`scene/set/${valueTypeName}`, 'Action', `Set Scene ${toCamelCase(valueTypeName)}`, (description, graph) => new SetSceneProperty(description, graph, valueTypeName, scene)));
    }
    triggered(fiber, triggeringSocketName) {
        const scene = this.scene;
        const value = this.readInput('value');
        scene.setProperty(this.readInput('jsonPath'), this.valueTypeName, value);
        fiber.commit(this, 'flow');
    }
}
//# sourceMappingURL=SetSceneProperty.js.map