import { In1Out1FuncNode } from '../../Nodes/Templates/In1Out1FuncNode.js';
import { In2Out1FuncNode } from '../../Nodes/Templates/In2Out1FuncNode.js';
import { In3Out1FuncNode } from '../../Nodes/Templates/In3Out1FuncNode.js';
import { ValueType } from '../../Values/ValueType.js';
import { VecCreate } from './Logic/VecCreate.js';
import { VecElements } from './Logic/VecElements.js';
import { angleAxisToQuat, quatConjugate, quatMultiply, quatSlerp, Vec4, vec4Dot, vec4FromArray, vec4Length, vec4Normalize, vec4Parse, vec4ToArray, vec4ToString } from './Values/Vec4.js';
export function registerQuatValue(registry) {
    const { nodes, values } = registry;
    values.register(new ValueType('quat', () => new Vec4(), (value) => typeof value === 'string'
        ? vec4Parse(value)
        : new Vec4(value.x, value.y, value.z, value.w), (value) => ({ x: value.x, y: value.y, z: value.z, w: value.w })));
    nodes.register('logic/create/quat', () => new VecCreate('logic/create/quat', 'quat', ['x', 'y', 'z', 'w'], (elements) => vec4FromArray(elements)));
    nodes.register('logic/quat', () => new In1Out1FuncNode('logic/quat', 'quat', 'quat', (a) => a));
    nodes.register('logic/elements/quat', () => new VecElements('logic/elements/quat', 'quat', ['x', 'y', 'z', 'w'], vec4ToArray));
    nodes.register('logic/angleAxis/quat', () => new In2Out1FuncNode('logic/angleAxis/quat', 'float', 'vec3', 'quat', (a, b) => angleAxisToQuat(a, b)));
    nodes.register('logic/multiply/quat', () => new In2Out1FuncNode('logic/multiply/quat', 'quat', 'quat', 'quat', (a, b) => quatMultiply(a, b)));
    nodes.register('logic/dot/quat', () => new In2Out1FuncNode('logic/dot/quat', 'quat', 'quat', 'float', (a, b) => vec4Dot(a, b)));
    nodes.register('logic/conjugate/quat', () => new In1Out1FuncNode('logic/conjugate/quat', 'quat', 'quat', (a) => quatConjugate(a)));
    nodes.register('logic/slerp/quat', () => new In3Out1FuncNode('logic/slerp/quat', 'quat', 'quat', 'float', 'quat', (a, b, c) => quatSlerp(a, b, c)));
    nodes.register('logic/normalize/quat', () => new In1Out1FuncNode('logic/normalize/quat', 'quat', 'quat', (a) => vec4Normalize(a)));
    nodes.register('logic/length/quat', () => new In1Out1FuncNode('logic/length/quat', 'quat', 'float', (a) => vec4Length(a)));
    nodes.register('logic/toString/quat', () => new In1Out1FuncNode('logic/toString/quat', 'quat', 'string', (a) => vec4ToString(a)));
}
//# sourceMappingURL=registerQuatValue.js.map